# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class BulkResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'errors': 'bool',
        'error': 'str'
    }

    attribute_map = {
        'items': 'items',
        'errors': 'errors',
        'error': 'error'
    }

    def __init__(self, items=None, errors=None, error=None, local_vars_configuration=None):  # noqa: E501
        """BulkResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items = None
        self._errors = None
        self._error = None
        self.discriminator = None

        if items is not None:
            self.items = items
        if errors is not None:
            self.errors = errors
        if error is not None:
            self.error = error

    @property
    def items(self):
        """Gets the items of this BulkResponse.  # noqa: E501


        :return: The items of this BulkResponse.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._items
    @items.setter
    def items(self, items):
        """Sets the items of this BulkResponse.


        :param items: The items of this BulkResponse.  # noqa: E501
        :type items: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._items = items
        

    @property
    def errors(self):
        """Gets the errors of this BulkResponse.  # noqa: E501


        :return: The errors of this BulkResponse.  # noqa: E501
        :rtype: bool
        """
        return self._errors
    @errors.setter
    def errors(self, errors):
        """Sets the errors of this BulkResponse.


        :param errors: The errors of this BulkResponse.  # noqa: E501
        :type errors: bool
        """

        self._errors = errors
        

    @property
    def error(self):
        """Gets the error of this BulkResponse.  # noqa: E501


        :return: The error of this BulkResponse.  # noqa: E501
        :rtype: str
        """
        return self._error
    @error.setter
    def error(self, error):
        """Sets the error of this BulkResponse.


        :param error: The error of this BulkResponse.  # noqa: E501
        :type error: str
        """

        self._error = error
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BulkResponse):
            return True

        return self.to_dict() != other.to_dict()
